@@ -433,7 +433,7 @@ public class GoogleEventConverter {
             public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getRecurringEventId() != null) {
                     try {
-                        if(from.getOriginalStartTime() != null) {
+                        if (from.getOriginalStartTime() != null) {
                             com.google.api.client.util.DateTime rfc3339 = from.getOriginalStartTime().getDate() == null ? from.getOriginalStartTime().getDateTime() : from.getOriginalStartTime().getDate();
                             RecurrenceId recId = new DefaultRecurrenceId(new DateTime(rfc3339.getValue()));
                             to.setRecurrenceId(recId);
@@ -452,7 +452,7 @@ public class GoogleEventConverter {
                      * This check expects that google ids of occurences to be in the following format: [masterId]_[recurrenceid]
                      * E.g.: 4qebqgd7o0nrqdlnqhberc4d3l_20171025T173000Z
                      */
-                    String dateTimeStr = from.getId().substring(from.getId().indexOf("_") + 1);
+                    String dateTimeStr = from.getId().substring(from.getId().indexOf('_') + 1);
                     try {
                         RecurrenceId recId = new DefaultRecurrenceId(dateTimeStr);
                         to.setRecurrenceId(recId);
