@@ -251,13 +251,6 @@ public class ICalFeedClient {
         }
 
         // Assert the 5xx codes
-        switch (statusCode) {
-            case 500:
-                throw ICalProviderExceptionCodes.REMOTE_INTERNAL_SERVER_ERROR.create(httpResponse.getStatusLine().getReasonPhrase());
-            case 503:
-                LOG.info("The previously existing feed '{}' seems to be removed.", iCalFeedConfig.getFeedUrl());
-                return statusCode;
-        }
         if (statusCode >= 500 && statusCode <= 599) {
             throw ICalProviderExceptionCodes.REMOTE_SERVER_ERROR.create(String.valueOf(httpResponse.getStatusLine()));
         }
@@ -273,7 +266,7 @@ public class ICalFeedClient {
         if (null != request) {
             try {
                 request.reset();
-            } catch (final Exception e) {
+            } catch (Exception e) {
                 // Ignore
             }
         }
@@ -293,7 +286,7 @@ public class ICalFeedClient {
                 synchronized (ICalFeedHttpClient.class) {
                     tmp = httpClient;
                     if (tmp == null) {
-                        ClientConfig config = ClientConfig.newInstance();
+                        ClientConfig config = ClientConfig.newInstance("icalfeed");
                         config.setDenyLocalRedirect(true);
                         config.setUserAgent(initUserAgent());
                         initConfig(config);
