@@ -74,17 +74,13 @@ public class SchedJoulesRESTClient extends AbstractRESTClient {
     private static final String LAST_MODIFIED_DATE_PATTERN = "EEE, dd MMM yyyy HH:mm:ss z";
     private final static ThreadLocal<SimpleDateFormat> LAST_MODIFIED_DATE_PARSER = new ThreadLocal<SimpleDateFormat>() {
 
-        /*
-         * (non-Javadoc)
-         *
-         * @see java.lang.ThreadLocal#initialValue()
-         */
         @Override
         protected SimpleDateFormat initialValue() {
             return new SimpleDateFormat(LAST_MODIFIED_DATE_PATTERN, java.util.Locale.US);
         }
     };
 
+    private static final String CLIENT_NAME = "schedjoules";
     private static final String USER_AGENT = "Open-Xchange SchedJoules Client";
     private static final int API_VERSION = 1;
 
@@ -100,7 +96,7 @@ public class SchedJoulesRESTClient extends AbstractRESTClient {
      * Initialises a new {@link SchedJoulesRESTClient}.
      */
     public SchedJoulesRESTClient(String scheme, String host, String apiKey, int timeout) {
-        super(USER_AGENT, timeout, new SchedJoulesRESTResponseParser());
+        super(CLIENT_NAME, USER_AGENT, timeout, new SchedJoulesRESTResponseParser());
 
         this.scheme = scheme;
         this.host = host;
