@@ -55,9 +55,8 @@ import com.openexchange.context.ContextService;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.oauth.OAuthAccountDeleteListener;
-import com.openexchange.subscribe.google.GoogleCalendarSubscribeService;
-import com.openexchange.subscribe.google.GoogleContactSubscribeService;
-
+import com.openexchange.server.ServiceLookup;
+import com.openexchange.subscribe.google.GoogleContactsSubscribeService;
 
 /**
  * {@link GoogleSubscriptionsOAuthAccountDeleteListener}
@@ -66,25 +65,23 @@ import com.openexchange.subscribe.google.GoogleContactSubscribeService;
  */
 public class GoogleSubscriptionsOAuthAccountDeleteListener implements OAuthAccountDeleteListener {
 
-    private final GoogleCalendarSubscribeService googleCalendarSubscribeService;
-    private final GoogleContactSubscribeService googleContactSubscribeService;
-    private final ContextService contexts;
+    private final GoogleContactsSubscribeService contactSubsrcibeService;
+    private final ServiceLookup services;
 
-    public GoogleSubscriptionsOAuthAccountDeleteListener(final GoogleCalendarSubscribeService calService, final GoogleContactSubscribeService contactService, final ContextService contexts) {
+    public GoogleSubscriptionsOAuthAccountDeleteListener(GoogleContactsSubscribeService contactService, ServiceLookup services) {
         super();
-        this.googleCalendarSubscribeService = calService;
-        this.googleContactSubscribeService = contactService;
-        this.contexts = contexts;
+        this.contactSubsrcibeService = contactService;
+        this.services = services;
     }
 
     @Override
     public void onAfterOAuthAccountDeletion(final int id, final Map<String, Object> eventProps, final int user, final int cid, final Connection con) throws OXException {
-        googleCalendarSubscribeService.deleteAllUsingOAuthAccount(getContext(cid), id);
-        googleContactSubscribeService.deleteAllUsingOAuthAccount(getContext(cid), id);
+        contactSubsrcibeService.deleteSubscription(getContext(cid), id);
     }
 
-    private Context getContext(final int cid) throws OXException {
-        return contexts.getContext(cid);
+    private Context getContext(int cid) throws OXException {
+        ContextService contextService = services.getService(ContextService.class);
+        return contextService.getContext(cid);
     }
 
     @Override
@@ -92,5 +89,4 @@ public class GoogleSubscriptionsOAuthAccountDeleteListener implements OAuthAccou
         // Nothing to do
 
     }
-
 }
